# @summary File URL
#
# Defines a .URL shortcut
#
# @param ensure
#   Desired state of the shortcut
#   Example: 'absent'
#
# @param file_name
#   Assigned text, including the file extension, that should be used as the name of the file
#   Example: 'ThanksForAllTheFish.url'
#
# @param hot_key
#   Denotes the key combination to assign to the shortcut
#   Key combo execution may not work when files are in areas that current user does not have direct rights to
#   Example: 1607
#
# @param icon_file
#   Full path to the file containing the icon to use for the shortcut
#   Example: 'C:\\Windows\\HelpPane.exe'
#
# @param icon_index
#   Denotes which entry within the icon_file file should be used
#   Example: 0
#
# @param log_output
#   Determines additional logging output (typically only used for troubleshooting) during a Puppet agent run
#   Example: True
#
# @param parent_folder
#   Fully qualified path to the parent folder that will house the shortcut
#   Example: 'C:\\Users\\Public\\Desktop'
#
# @param url
#   URL to navigate to when the shortcut is executed
#   Example: 'https://forge.puppet.com'
#
define file_url (
  String $file_name,
  String $parent_folder,
  String $url,
  Optional[Enum['present', 'absent']] $ensure = 'present',
  Optional[Integer] $hot_key = 0,
  Optional[String] $icon_file = 'absent',
  Optional[Integer] $icon_index = -1,
  Optional[Boolean] $log_output = false,
) {
  if ($log_output) {
    notify {"${module_name} - ${title} - file_name: '${file_name}'":}
    notify {"${module_name} - ${title} - ensure: '${ensure}'":}
    notify {"${module_name} - ${title} - parent_folder: '${parent_folder}'":}
  }
  if ($ensure == 'absent') {
    tidy { "Remove ${title} LNK shortcut":
      path    => $parent_folder,
      age     => '0',
      recurse => 1,
      matches => [ $file_name ],
    }
  } else {
    if ($log_output) {
      notify {"${module_name} - ${title} - url: '${url}'":}
      notify {"${module_name} - ${title} - icon_file: '${icon_file}'":}
      notify {"${module_name} - ${title} - icon_index: '${icon_index}'":}
    }
    exec { "Set '${title}' URL shortcut":
      provider  => powershell,
      command   => template(
        "${module_name}/helpers.ps1.erb",
        "${module_name}/command.ps1.erb"
      ),
      onlyif    => template(
        "${module_name}/helpers.ps1.erb",
        "${module_name}/onlyif.ps1.erb"
      ),
      logoutput => $log_output
    }
  }
}
